Learn R Programming

csodata (version 1.4.2)

cso_disp_geo_meta: Prints metadata from an ESRI shapefile to console

Description

Takes the output from cso_get_geo or otherwise and prints information about it to the console as formatted text.

Usage

cso_disp_geo_meta(shp)

Value

Does not return any values, rather the function prints the shapefile metadata to console.

Arguments

shp

sf data.frame. Geographic data stored as an sf object.

Examples

Run this code
if (FALSE) {
cso_disp_geo_meta(shp)
}

Run the code above in your browser using DataLab