Learn R Programming

csodata (version 1.4.2)

cso_disp_meta: Prints metadata from a PxStat table to the console

Description

Takes the output from cso_get_meta and prints it to the console as formatted text.

Usage

cso_disp_meta(table_code)

Value

Does not return any values, rather the function prints the tables metadata to console.

Arguments

table_code

string. A valid code for a table on data.cso.ie .

Examples

Run this code
if (FALSE) {
cso_disp_meta("EP001")
}

Run the code above in your browser using DataLab