Learn R Programming

csodata (version 1.4.2)

cso_get_geo_meta: Returns a data frame with the metadata of a vector shapefile

Description

Takes the output from cso_get_geo or otherwise and returns information about it in a data frame.

Usage

cso_get_geo_meta(shp)

Value

list with eight elements:

  • The coordinate reference system, itself a list with two elements, the EPSG code (if any, NA value if none), and the proj4string

  • The number of polygons in the data

  • If all the polygons are simple (not self-intersecting)

  • If any polygons are empty

  • If all of the polygons are valid

  • The average area of the polygons, including units

Arguments

shp

sf data.frame. Geographic data stored as an sf object.

Examples

Run this code
if (FALSE) {
shp_meta <- cso_get_geo_meta(shp)
}

Run the code above in your browser using DataLab