The title of the table.
The units used (the R class of the value column)
The Copyright on the data.
The time interval used in the data. (Census year, Quarter, Month)
The date the table was last modified.
The names of the variables included in the table, returned as a
character vector with one element for each variable.
The names of the statistics included in the table, returned as a
character vector with one element for each statistic.
An indicator if the statistics are experimental
Returns if the data is geographic