character vector. The names of the statistics included in the
table.
Arguments
table_code
string. A valid code for a table on data.cso.ie .
cache
logical. Whether to use cached data, if available.
Default value is TRUE. Strongly recommended to use caching, as otherwise
the entire table could be downloaded only to access a small part of its
metadata.
flush_cache
logical. If TRUE (default) the cache will be checked for old, unused
files. Any files which have not been accessed in the last month will be deleted.