powered by
Takes the output from cso_get_geo or otherwise and prints information about it to the console as formatted text.
cso_get_geo
cso_disp_geo_meta(shp)
Does not return any values, rather the function prints the shapefile metadata to console.
sf data.frame. Geographic data stored as an sf object.
if (FALSE) { cso_disp_geo_meta(shp) }
Run the code above in your browser using DataLab