powered by
Takes the output from cso_get_meta and prints it to the console as formatted text.
cso_get_meta
cso_disp_meta(table_code)
Does not return any values, rather the function prints the tables metadata to console.
string. A valid code for a table on data.cso.ie .
if (FALSE) { cso_disp_meta("EP001") }
Run the code above in your browser using DataLab