powered by
Takes the output from cso_get_geo or otherwise and returns information about it in a data frame.
cso_get_geo
cso_get_geo_meta(shp)
list with eight elements:
The coordinate reference system, itself a list with two elements, the EPSG code (if any, NA value if none), and the proj4string
The number of polygons in the data
If all the polygons are simple (not self-intersecting)
If any polygons are empty
If all of the polygons are valid
The average area of the polygons, including units
sf data.frame. Geographic data stored as an sf object.
if (FALSE) { shp_meta <- cso_get_geo_meta(shp) }
Run the code above in your browser using DataLab